Index: trunk/MagicSoft/Mars/manalysis/MCerPhotCalc.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MCerPhotCalc.h	(revision 1127)
+++ trunk/MagicSoft/Mars/manalysis/MCerPhotCalc.h	(revision 1128)
@@ -18,13 +18,13 @@
 class MPedestalCam;
 class MCerPhotEvt;
+class MRawRunHeader;
 
 class MCerPhotCalc : public MTask
 {
-    const MPedestalCam *fPedestals;  // Pedestals of all pixels in the camera
-          MRawEvtData  *fRawEvt;     // raw event data (time slices)
-          MCerPhotEvt  *fCerPhotEvt; // Cerenkov Photon Event used for calculation
-	  UShort_t fNumLoGainFadcSlices;      //
-	  UShort_t fNumHiGainFadcSlices;      //
-
+    const MPedestalCam  *fPedestals;  // Pedestals of all pixels in the camera
+          MRawEvtData   *fRawEvt;     // raw event data (time slices)
+          MCerPhotEvt   *fCerPhotEvt; // Cerenkov Photon Event used for calculation
+	  MRawRunHeader *fRunHeader;  //  RunHeader information
+ 
 public:
     MCerPhotCalc(const char *name=NULL, const char *title=NULL);
